import React, { useState, useEffect } from 'react';
import { Select } from 'antd';
import { getSelectName } from '../../../../apis/process';

const { Option } = Select;

const SelectTree = ({ value, onChange, schema }) => {

  const { disabled, placeholder } = schema
  const [selectList, setSelectList] = useState([]);
  const [mode, setMode] = useState('');
  // 判断当前时单选还是多选
  const _configArray = schema.config.split('.');
  const isMultiple = !!(_configArray[2] && _configArray[2] === 'n');

  const val = value || schema.default;

  const handleChange = value => {
    onChange(value);
  };

  const getData = () => {
    const arr = schema.config.split('.');
    if (!arr.length) return false;
    // 区别于搜索选择器
    const dictionaryName = arr[1] || arr[0];
    if (isMultiple) {
      setMode('multiple');
    } else {
      setMode('');
    }
    getSelectName(dictionaryName).then(res => {
      if (res.code === 0) {
        let _list = res.data;
        if (schema.filterKey) _list = _list.filter(item => item.nodeName === schema.filterKey);
        setSelectList(_list);
      } else {
        onChange('请求错误');
      }
    });
  };

  useEffect(() => {
    const handleInitData = Object.prototype.toString.call(val) === '[object String]' && val ? val.split(',') : val;
    let _val = isMultiple ? handleInitData : val;
    onChange(_val);
  }, []);

  return (
    <Select
      disabled={disabled}
      mode={mode}
      showSearch
      optionFilterProp="children"
      value={null}
      onChange={handleChange}
      onFocus={() => getData()}
      placeholder={placeholder}
      style={{ width: '100%' }}
    >
      {selectList.map((item, index) => {
        return (
          <Option value={item.nodeValue} key={index}>
            {item.nodeValue}
          </Option>
        );
      })}
    </Select>
  )

}

export default SelectTree
